/*
 *
 * Core Interface for Kaspersky AntiVirus
 *
 * Copyright (C) Ries van Twisk, vscan@rvt.dds.nl, 2002
 * Copyright (C) Rainer Link, rainer@openantivirus.org, 2002
 *
 * This software is licensed under the GNU General Public License (GPL)
 * See: http://www.gnu.org/copyleft/gpl.html
 *
*/

#include "vscan-kavp.h"
#include "vscan-kavp_core.h"
#include "kavclient.h"
#include <includes.h>

/* Scan a file */
/* return 
    0  everything is ok 
    -1 File contains a virii
    -2 socket is not open
    -3 request path file
    -4 response failes
*/


/* print a message via syslog */
void vscan_kavp_print(char *printMessage, ...)
{
        char printMsg[512];

        va_list argptr;
        va_start(argptr, printMessage);
        vsnprintf(printMsg, sizeof(printMsg)-1, printMessage, argptr);
        va_end(argptr);

        syslog(SYSLOG_PRIORITY, "%s", printMsg);
}


/*
  If virus is found, logs the filename/virusname into syslog
*/
void vscan_kavp_log_virus(char *infected_file)
{
	// there seems no way to get the virus name :(        
	static char virusName[] = "UNKNOWN";

	vscan_kavp_print("Scan result: '%s' infected with virus '%s' - Access denied", infected_file, virusName);
        
}



int vscan_kavp_scanfile(char *scan_file)
{
	int result;
	char* response;
	int exit_code;

	/* Check the socket */
	if (kavp_socket == 0) {
	    vscan_kavp_print("vscan-kavp: connection to kavpdaemon was not open!\n");
    	    return -2;
	};	

	
	/* Send scan request to kavdaeon */
	#if VSCAN_KAVP_VERBOSE_FILE_LOGGING==1
	vscan_kavp_print("vscan-kavp: KAVRequestPath() scanning file [%s]\n", scan_file);
	#endif

	if ( (result=KAVRequestPath(kavp_socket, scan_file, SILENT )) < 0) {
	    vscan_kavp_print("vscan-kavp: KAVRequestMulti() failed (return code: [%d])\n", result);
	    return -3;
	};

	/* Receive status back about this file */	
	if ( (response=KAVResponse(kavp_socket, &exit_code, SILENT, 0)) ==0 ) {
	    vscan_kavp_print("vscan-kavp: KAVResponse() failed (return code: [0])\n");
	    return -4;
	};	
    
	if ((exit_code & 0xff) - 0x30) {
	    vscan_kavp_log_virus(scan_file);
	    return -1;	// Found a virus deny
	} else {
	    #if VSCAN_KAVP_VERBOSE_FILE_LOGGING==1
	    vscan_kavp_print("file %s is clean", scan_file);
	    #endif
	    return 0;	// Everything seems to be ok
	};
}

/* Initialize VSAPI */
void vscan_kavp_init(void)
{
    kavp_socket = KAVConnect(AVPCTL, SILENT);
    if ( kavp_socket < 0 ) {
	vscan_kavp_print("vscan-kavp:KAVConnect() failed (return code: [%d])\n", kavp_socket);
    }
}

/* Bye, bye, VSAPI */
void vscan_kavp_end(void)
{
    int result;
    if (kavp_socket>0) {
	if ((result=KAVClose(kavp_socket, SILENT)) ==0 )
    	    vscan_kavp_print("vscan-kavp:Disconnected from kavdaemon.\n");	
	else
    	   vscan_kavp_print("vscan-kavp:KAVClose() failed (return code: [%d])\n", result);	
	kavp_socket = -1;
    } else {
	vscan_kavp_print("vscan-kavp:Not closing a closed connection\n");
    };
}


