#ifndef __VSCAN_SOPHOS_H_
#define __VSCAN_SOPHOS_H_

#include "config.h"

#include <sys/types.h>

#ifdef TIME_WITH_SYS_TIME
 #include <sys/time.h>
 #include <time.h>
#else
 #ifdef HAVE_SYS_TIME_H
  #include <sys/time.h>
 #else
  #include <time.h>
 #endif
#endif


#ifdef HAVE_UTIME_H
 #include <utime.h>
#endif

#ifdef HAVE_DIRENT_H
 #include <dirent.h>
#endif

#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
#else
 #ifdef HAVE_SYS_FCNTL_H
  #include <sys/fcntl.h>
 #endif
#endif

#include <stdio.h>

#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
#endif

#include <syslog.h>

#ifdef HAVE_STDARG_H
 #include <stdarg.h>
#else
 #include <varargs.h>
#endif


#ifdef HAVE_UNISTD_H
 #include <unistd.h>
#endif

#ifdef HAVE_STRING_H
 #include <string.h>
#endif

#ifdef HAVE_STRINGS_H
 #include <strings.h>
#endif


#include <errno.h>
#include <pwd.h>
#include <sys/stat.h>



/* Configuration Section :-) */

/* which samba version is this VFS module compiled for:
 * Set SAMBA_VERSION_MAJOR to 3 for Samba 3.0 alpha0 or
 * to 2 for Samba 2.2.x
 * Set SAMBA_VERSION_MINOR to 2 if you're using Samba 2.2.2 or
 * to 1 if you're using Samba 2.2.0[a] or 0 for Samba 2.2.0[a] 
 * If SAMBA_VERSION_MAJOR is set to 3, SAMBA_VERSION_MINOR
 * is ignored!
*/

#ifndef SAMBA_VERSION_MAJOR
# define SAMBA_VERSION_MAJOR 2 
#endif

#ifndef SAMBA_VERSION_MINOR
# define SAMBA_VERSION_MINOR 2
#endif 

/* 0 = log only infected file, 1 = log every file access */

#ifndef VSCAN_SOPHOS_VERBOSE_FILE_LOGGING
# define VSCAN_SOPHOS_VERBOSE_FILE_LOGGING 0   
#endif

/* if a file is bigger than VSCAN_SOPHOS_MAX_SIZE it won't be scanned. Has to be
   specified in bytes! If it set to 0, the file size check is disabled */

#ifndef VSCAN_SOPHOS_MAX_SIZE 
# define VSCAN_SOPHOS_MAX_SIZE 0 
#endif

/* End Configuration Section */


#ifndef SYSLOG_FACILITY
#define SYSLOG_FACILITY   LOG_USER
#endif

#ifndef SYSLOG_PRIORITY
#define SYSLOG_PRIORITY   LOG_NOTICE
#endif

#ifndef bool 
 #ifndef BOOL_DEFINED
   typedef int bool;
 #endif
#endif 

#ifndef FALSE
# define FALSE	0
#endif /* ! FALSE */
#ifndef TRUE
# define TRUE	1
#endif /* ! TRUE */



/* functions by vscan-sophie_core */
/* initialize SAVI */
void vscan_sophos_init(void); 
/* print a message via syslog */
void vscan_sophos_print(char *printMessage, ...);
/* scans a file */
int vscan_sophos_scanfile(char *scan_file);
/* terminates SAVI */
void vscan_sophos_end(void);

/* various constants to customize SAVI - you may change them for your needs 
   please see the SAVI documentation (savitoolkit.pdf), chapter SAVI Engine
   settings for details. It's available at 
   http://www.sophos.com/downloads/products/savi.html */  

#define VSCAN_SOPHOS_DO_FULL_SWEEP 		"1"
#define VSCAN_SOPHOS_DYNAMIC_DECOMPRESSION "1"
#define VSCAN_SOPHOS_FULL_MACRO_SWEEP 		"1"
#define VSCAN_SOPHOS_IGNORE_TEMPLATE_BIT	"1"
#define VSCAN_SOPHOS_OLE2_HANDLING			"1"
#define VSCAN_SOPHOS_VBA3_HANDLING			"1"
#define VSCAN_SOPHOS_VBA5_HANDLING			"1"
#define VSCAN_SOPHOS_DECOMPRESS_VBA5		"1"
#define VSCAN_SOPHOS_DO_EMULATION 			"1"
#define VSCAN_SOPHOS_PE_HANDLING			"1"
#define VSCAN_SOPHOS_XF_HANDLING			"1"
#define VSCAN_SOPHOS_PM97_HANDLING			"1"
#define VSCAN_SOPHOS_ZIP_DECOMPRESSION		"1"
#define VSCAN_SOPHOS_ARJ_DECOMPRESSION		"1"
#define VSCAN_SOPHOS_RAR_DECOMPRESSION		"1"
#define VSCAN_SOPHOS_UUE_DECOMPRESSION		"1"
#define VSCAN_SOPHOS_GZIP_DECOMPRESSION	"1"
#define VSCAN_SOPHOS_TAR_DECOMPRESSION		"1"
#define VSCAN_SOPHOS_CMZ_DECOMPRESSION		"1"
#define VSCAN_SOPHOS_MAX_RECURSION_DEPTH	"16"

#define VSCAN_SOPHOS_LHA_DECOMPRESSION		"1"
#define VSCAN_SOPHOS_SFX_HANDLING			"1"
#define VSCAN_SOPHOS_MSCABINET_HANDLING	"0" /* Seems this is not supported on UNIX */
#define VSCAN_SOPHOS_TNEF_HANDLING			"1"
#define VSCAN_SOPHOS_MSCOMPRESS_HANDLING	"1"
#define VSCAN_SOPHOS_OF95DECRYPT_HANDLING	"1"
#define VSCAN_SOPHOS_DELETE_ALL_MACROS 	"0" /* Do not set this to '1' - it won't find any viruses, but will just try to remove macros (I think - no details in docs)! */

#define VSCAN_SOPHOS_VBE					"1" /* Just a wild guess - 'heuristics' on VBE files (embedded somewhere or not - who knows) */
#define VSCAN_SOPHOS_EXEC_FILE_DISINFECT	"0" /* I don't think this will be needed (Sophie doesn't disinfect anything) */
#define VSCAN_SOPHOS_VISIO_FILE_HANDLING	"1" /* Wild guess - 'analyzing' Visio (.vsd) files - now that Micro$oft bought Visio, they made sure people can embed viruses in it too */

#endif /* __VSCAN_SOPHOS_H_ */
