/* 
 * $Id: vscan-symantec_core.c,v 1.0 2002/03/06 15:45:24 reniar Exp $	
 *
 * Core Interface for Symantec Carrier Scan			
 *
 * Copyright (C) Rainer Link, SuSE GmbH <link@suse.de>, 2001-2002
 *                            OpenAntiVirus.org <rainer@openantivirus.org>
 *
 * This software is licensed under the GNU General Public License (GPL)
 * See: http://www.gnu.org/copyleft/gpl.html
 *
*/

#include "vscan-symantec_core.h"
 

bool cscan_ok = TRUE;

HSCANCLIENT scanclient=NULL;



/* print a message via syslog */
void vscan_symantec_print(char *printMessage, ...)
{
        char printMsg[512];

        va_list argptr;
        va_start(argptr, printMessage);
        vsnprintf(printMsg, sizeof(printMsg)-1, printMessage, argptr);
        va_end(argptr);

	syslog(SYSLOG_PRIORITY, "%s", printMsg);
}




/* initialise CarrierScan */
void vscan_symantec_init(void)
{
	char pszStartUpString[MAX_STRING];

	sprintf(pszStartUpString, "server:%s", CS_IP_PORT);

        if ( ScanClientStartUp( &scanclient, pszStartUpString) > 0 ) 
        {
                vscan_symantec_print("ERROR in ScanClientStartUp\n");
        	cscan_ok = FALSE;        
        }

}

/*
void vscan_symantec_syslog(char *syslogMessage, ...)
{
        char logMsg[512];

        va_list argptr;
        va_start(argptr, syslogMessage);
        vsnprintf(logMsg, sizeof(logMsg)-1, syslogMessage, argptr);
        va_end(argptr);

        syslog(SYSLOG_PRIORITY, "%s\n", logMsg);
}

*/

/*
  If virus is found, logs the filename/virusname into syslog
*/
void vscan_symantec_log_virus(char *infected_file, HSCANRESULTS hResults)
{
	char virusName[MAX_STRING];
	int attrib_size;

	attrib_size = MAX_STRING;
	ScanResultGetProblem( hResults, 0, SC_PROBLEM_VIRUSNAME, virusName, &attrib_size ); 

	
        vscan_symantec_print("Scan result: '%s' infected with virus '%s' - Access denied", infected_file, virusName);
        
}



/*
  Scans a file (*FILE*, not a directory - keep that in mind) for a virus
*/
int vscan_symantec_scanfile(char *scan_file)
{
	HSCANRESULTS results=NULL; 
        SCSCANFILE_RESULT answer;


	#if VSCAN_SYMANTEC_VERBOSE_FILE_LOGGING==1
        vscan_symantec_print("Scanning file : '%s'", scan_file);
	#endif

	answer = ScanClientScanFile( scanclient, scan_file, scan_file, NULL, "", &results ); 
        if( answer > 0 )
        { 
                vscan_symantec_print( "**** ERROR! Couldn't scan file %s\n", scan_file); 
                return -1;
        }


        switch (answer)
        {
		case SCSCANFILE_INF_NO_REP:
		case SCSCANFILE_INF_PARTIAL_REP:
		case SCSCANFILE_INF_REPAIRED:
			vscan_symantec_log_virus(scan_file, results);
			ScanResultsFree(results); 
			return 1;
			break;

		case SCSCANFILE_CLEAN:
			#if VSCAN_SYMANTEC_VERBOSE_FILE_LOGGING==1
			vscan_symantec_print("file %s is clean", scan_file);
			#endif
			ScanResultsFree(results);
              	  	return 0;
			break;
		default:
			vscan_symantec_print("ScanClientScanFile returned an unexpected value\n");
			ScanResultsFree(results);
			return -1;
       }
	
}

/*
  Cleanup
*/
void vscan_symantec_end(void)
{

	ScanClientShutDown(scanclient); 

        vscan_symantec_print("C API for CarrierScan cleaned up and released/terminated");

}
